@@ -35,11 +35,14 @@
 # define iconv_open(tocode, fromcode) ((iconv_t) -1)
 
 # undef iconv
-# define iconv(cd, inbuf, inbytesleft, outbuf, outbytesleft) ((size_t) 0)
+# define iconv(cd, inbuf, inbytesleft, outbuf, outbytesleft) (errno = ENOSYS, (size_t) -1)
 
 # undef iconv_close
 # define iconv_close(cd) 0
 
+# undef iconv_t
+# define iconv_t int
+
 #endif
 
 
@@ -81,7 +84,18 @@ utf8_convert (bool to_utf, char const *input, char **output)
   outlen = inlen * MB_LEN_MAX + 1;
   ob = ret = xmalloc (outlen);
   ib = (char ICONV_CONST *) input;
-  if (iconv (cd, &ib, &inlen, &ob, &outlen) == -1)
+  /* According to POSIX, "if iconv() encounters a character in the input
+     buffer that is valid, but for which an identical character does not
+     exist in the target codeset, iconv() shall perform an
+     implementation-defined conversion on this character." It will "update
+     the variables pointed to by the arguments to reflect the extent of the
+     conversion and return the number of non-identical conversions performed".
+     On error, it returns -1. 
+     In other words, non-zero return always indicates failure, either because
+     the input was not fully converted, or because it was converted in a
+     non-reversible way.
+   */
+  if (iconv (cd, &ib, &inlen, &ob, &outlen) != 0)
     {
       free (ret);
       return false;
